@@ -1,10 +1,10 @@
-import tv2ts
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
 # Copyright (C) 2009-2011 Yukikaze
 #import sys
 import epgdb
+import tv2ts
 import os
 import time
 import tv2avi
@@ -44,4 +44,4 @@ recpath = "/home/ftpusr/ftp-tmp/Recording/"
 ftpusr = "/home/ftpusr/ftp-tmp"
 recordedpath = u"/home/ftpusr/ftp-video"
 if __name__ == "__main__":
-    ""
\ No newline at end of file
+    rec10d.rec10db.update_db_98to100()
\ No newline at end of file
