@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 import commands
 import shutil
 import auto_process
@@ -13,6 +13,7 @@ import base64
 import time
 import subprocess
 import traceback
+import zip
 
 import tv2avi
 import recdblist
@@ -26,6 +27,8 @@ def ts2mp4(pin, pout, opt):
     title=os.path.splitext(title)[0]
     tpraw=os.path.join(dir, title+".264")
     tpmp4=os.path.join(dir, title+".mp4")
+    if re.search("d",opt) and not os.path.exists(pin.replace(".ts",".m2v")):
+        tv2audio.ts2dualaudio_BonTsDemux(pin,recdblist.BONTSDEMUX_DELAY, opt)
     if os.path.isfile(pin) and os.path.getsize(pin)>10*1000:
         tv2avi.ts2raw(pin, tpraw, opt)
         time.sleep(10)
@@ -34,6 +37,9 @@ def ts2mp4(pin, pout, opt):
         time.sleep(10)
         if os.path.exists(tpraw):
             os.remove(tpraw)
+    zip.addFile2FileZip(recdblist.getLogTitle(pin)+".command.log", recdblist.getLogTitle(pin)+".log.zip")
+    if os.path.exists(recdblist.getLogTitle(pin)+".command.log"):
+        os.remove(recdblist.getLogTitle(pin)+".command.log")
 def raw2mp4(pin,pout,opt):
     dir=os.path.split(pout)[0]
     title=os.path.split(pout)[1]
@@ -49,7 +55,7 @@ def raw2mp4(pin,pout,opt):
         duration="-fps 29.970030 "##ffmpegが24fpsに対応していないための措置
     if re.search("I",opt):
         duration="-fps 29.970030 "
-    exe = configreader.getpath("mp4box")
+    exe = configreader.getConfPath("mp4box")
     txt=""
     os.environ['LANG']="ja_JP.UTF-8"
     pints=pin.replace(".264",".ts")
@@ -57,21 +63,17 @@ def raw2mp4(pin,pout,opt):
     execmp4box(pin, pout, e1)
     addAudio(pints, pout, opt)
     addCaption(pints, pout)
-    #recdblist.addlog(pout, txt, "mp4boxログ-コマンド")
-    #recdblist.addlog(pout, txt, "mp4boxログ-詳細")
     if status.getSettings_auto_del_tmp()==1:
         if os.path.exists(pout):
-            if re.search(opt,"MW8") or re.search(opt,"MW9"):
-                auto_process.deltmpfile(dir, title, ".mp4")
-            elif re.search(opt,"8") or re.search(opt,"9"):
-                ""
+            if re.search(opt,"1") or re.search(opt,"2"):
+                auto_process.deleteTmpFile(dir, title, ".mp4")
             else:
-                auto_process.deltmpfile(dir, title, ".mp4")
+                auto_process.deleteTmpFile(dir, title, ".mp4")
 def mkv2mp4(pin,pout):
-    exeb = configreader.getpath(u"mkvextract")
-    exe = configreader.getpath(u"mp4Box")
-    #dtsedit=configreader.getpath("DtsEdit")
-    wineexe=configreader.getpath("wine")
+    exeb = configreader.getConfPath(u"mkvextract")
+    exe = configreader.getConfPath(u"mp4Box")
+    #dtsedit=configreader.getConfPath("DtsEdit")
+    wineexe=configreader.getConfPath("wine")
     dir=os.path.split(pin)[0]
     title=os.path.split(pin)[1]
     title=os.path.splitext(title)[0]
@@ -93,17 +95,17 @@ def mkv2mp4(pin,pout):
         txt=txt+execcomd(exe3)+"\n"
     except:
         ""
-    recdblist.addlog(pin, txt, u"MKV2MP4-log")
+    recdblist.addLog(pin, txt, u"MKV2MP4-log")
     txt = "\n####MKV2MP4-log####\n"+txt
     time.sleep(10)
     if status.getSettings_auto_del_tmp()==1:
         if os.path.exists(pout):
-            auto_process.deltmpfile(dir, title, ".mp4")
+            auto_process.deleteTmpFile(dir, title, ".mp4")
 def addCaption(pts,pmp4):##字幕の追加を試みる。
-    wineexe=configreader.getpath("wine")
+    wineexe=configreader.getConfPath("wine")
     pincap=pts.replace(".ts",".srt")
     try:
-        cap2ass=configreader.getpath("caption2ass")
+        cap2ass=configreader.getConfPath("caption2ass")
     except:
         cap2ass=""
     if os.path.isfile(cap2ass):
@@ -117,16 +119,17 @@ def addCaption(pts,pmp4):##字幕の追加を試みる。
             #else:
             os.waitpid(p0.pid, 0)
             logt=unicode(p0.communicate()[0], "UTF-8")
-            recdblist.addlog(pts,e0, u"Captionログ-コマンド")
-            recdblist.addlog(pts,logt, u"Captionログ-詳細")
+            recdblist.addLog(pts,e0, u"Captionログ-コマンド")
+            recdblist.addLog(pts,logt, u"Captionログ-詳細")
+            recdblist.addCommandLogZip(pts, "mp4box_caption", "mp4box_caption", e0, logt)
         if os.path.exists(pincap):
             if os.path.getsize(pincap)>1000:
-                exe = configreader.getpath("mp4box")
+                exe = configreader.getConfPath("mp4box")
                 e1s=exe +u" -add \""+pincap+"\" \""+pmp4+"\""
                 addmp4(pincap,pmp4,e1s)
-def addAudio(pts,pmp4,opt):#オプションに応じた音声の追加を行う
-    exe = configreader.getpath("mp4box")
-    if re.search("d",opt) or re.search("5",opt):#二カ国語放送/5.1ch放送の場合
+def addAudio(pts,pmp4,opts):#オプションに応じた音声の追加を行う
+    exe = configreader.getConfPath("mp4box")
+    if re.search("d",opts) or re.search("5",opts):#二カ国語放送/5.1ch放送の場合
         paac1=pts.replace(".ts","_1.aac")
         paac2=pts.replace(".ts","_2.aac")
         recdblist.printutf8(paac1)
@@ -141,7 +144,7 @@ def addAudio(pts,pmp4,opt):#オプションに応じた音声の追加を行う
         if os.path.exists(paac2):
             addmp4(paac2, pmp4, e1a2)
     else:
-        tv2audio.ts2single_audio(pts)
+        tv2audio.ts2single_audio(pts,opts)
         pinaac=pts.replace(".ts",".aac")
         if not os.path.exists(pinaac):
             pinaac=pinaac.replace(".aac",".mp3")
@@ -161,6 +164,7 @@ def execmp4box(pin,pout,cmd):
     cmdn=string.replace(cmd,pin,ptin)
     cmdn=string.replace(cmdn,pout,ptout)
     recdblist.printutf8(cmdn)
+    recdblist.addCommandSelfLog(pin, cmdn)
     txt=""
     try:
         txt=execcomd(cmdn)
@@ -168,9 +172,10 @@ def execmp4box(pin,pout,cmd):
         txt= "error occures in execmp4box\n"
         txt=txt+ str(type(inst))+"\n"
         txt=txt+str(inst)
-        recdblist.Commonlogex("Error", "excecmp4box(tv2mp4.py)", str(type(inst)), str(inst)+traceback.format_exc(),verbose_level=200,log_level=200)
-    recdblist.addlog(pin, cmdn, u"MP4Boxログ-コマンド")
-    recdblist.addlog(pin, txt, u"MP4Boxログ-詳細")
+        recdblist.addCommonlogEX("Error", "excecmp4box(tv2mp4.py)", str(type(inst)), str(inst)+traceback.format_exc(),verbose_level=200,log_level=200)
+    recdblist.addLog(pin, cmdn, u"MP4Boxログ-コマンド")
+    recdblist.addLog(pin, txt, u"MP4Boxログ-詳細")
+    recdblist.addCommandLogZip(pin, "MP4Box", "mp4box", cmdn,txt)
     time.sleep(5)
     shutil.move(ptin,pin)
     shutil.move(ptout,pout)
@@ -200,8 +205,9 @@ def addmp4(padd,pout,cmd):#without video
         txt= "error occures in addmp4\n"
         txt=txt+ str(type(inst))+"\n"
         txt=txt+str(inst)
-    recdblist.addlog(pout, cmdn, u"MP4Box追加ログ-コマンド")
-    recdblist.addlog(pout, txt, u"MP4Box追加ログ-詳細")
+    recdblist.addLog(pout, cmdn, u"MP4Box追加ログ-コマンド")
+    recdblist.addLog(pout, txt, u"MP4Box追加ログ-詳細")
+    recdblist.addCommandLogZip(pout, "MP4Box_add", "mp4box_add", cmdn, txt)
     time.sleep(5)
     shutil.move(ptadd,padd)
     if os.path.exists(ptout):
@@ -209,7 +215,7 @@ def addmp4(padd,pout,cmd):#without video
         os.remove(ptoutb)
     else:
         txtt=padd+u"のインポートエラー"
-        recdblist.addlog(pout, txtt, u"MP4Box追加ログ-コマンド")
+        recdblist.addLog(pout, txtt, u"MP4Box追加ログ-コマンド")
         shutil.move(ptoutb,pout)
     time.sleep(5)
 def execcomd(cmd):
@@ -220,4 +226,4 @@ def execcomd(cmd):
         txt=txt+unicode(txt2,"utf-8")+"\n"
     except:
         ""
-    return txt
\ No newline at end of file
+    return txt
